use crossterm::event::Event;
use derive_more::derive::Constructor;
use kameo::{mailbox::unbounded::UnboundedMailbox, Actor};

use crate::{on_actor_start, publish, MessageBus};

use super::input_handler::{UserInput, UserInputEnum};

#[derive(Debug, Constructor)]
pub struct UserInputActor {
    user_input_bus: MessageBus<UserInput>,
}

impl Actor for UserInputActor {
    type Mailbox = UnboundedMailbox<Self>;

    on_actor_start!(this, actor_ref, {
        let user_input_bus = &this.user_input_bus;
        loop {
            match ratatui::crossterm::event::read()? {
                Event::Key(key_event) => {
                    publish!(
                        user_input_bus,
                        UserInput::new(UserInputEnum::KeyEvent(key_event))
                    )?;
                }
                Event::Resize(_, _) => {
                    publish!(user_input_bus, UserInput::new(UserInputEnum::Resize))?;
                }
                _ => {}
            }
        }
    });
}
