use kameo::message::Message;

use crate::{
    core::git::UserNotification,
    repo::messages::ValidateRepo,
    tell,
    xui::{
        state::{RepoStateStatus, UiFocus},
        Xui,
    },
};

use super::UserInterventionR;

impl Message<UserInterventionR> for Xui {
    type Reply = color_eyre::Result<()>;

    async fn handle(
        &mut self,
        _msg: UserInterventionR,
        _ctx: kameo::message::Context<'_, Self, Self::Reply>,
    ) -> Self::Reply {
        let index = self.state.ui.selected_forge_index;
        if let Some((_, repo_state)) = self.state.data.repos().get(index) {
            if let Some(repo_actor) = &repo_state.repo_actor {
                if let RepoStateStatus::UserIntervention { notification } = &repo_state.status {
                    match notification {
                        UserNotification::CICheckFailed { .. }
                        | UserNotification::RepoConfigLoadFailure { .. }
                        | UserNotification::WebhookRegistration { .. } => {
                            tell!(repo_actor, ValidateRepo::new(repo_state.message_token))?;
                        }
                        UserNotification::DevNotBasedOnMain { .. } => {
                            self.state.ui.focus = UiFocus::DevRebaseConfirm;
                            self.draw()?;
                        }
                    }
                }
            }
        }

        Ok(())
    }
}
